@@ -12,8 +12,8 @@ from sila2.framework.utils import run_protoc
 pb2_module, grpc_module = run_protoc(join(resource_dir, "proto", "SiLABinaryTransfer.proto"))
 
 if TYPE_CHECKING:
-    from sila2.pb2_stubs import SiLABinaryTransfer_pb2, SiLABinaryTransfer_pb2_grpc
-    from sila2.pb2_stubs.SiLAFramework_pb2 import Binary as SilaBinary
+    from sila2.framework.pb2 import SiLABinaryTransfer_pb2, SiLABinaryTransfer_pb2_grpc
+    from sila2.framework.pb2.SiLAFramework_pb2 import Binary as SilaBinary
 
     pb2_module = SiLABinaryTransfer_pb2
     grpc_module = SiLABinaryTransfer_pb2_grpc
