@@ -1,22 +1,18 @@
 from __future__ import annotations
 
 import uuid
-from typing import TYPE_CHECKING
 from typing import Any as TypingAny
-from typing import NamedTuple, Optional, Type
+from typing import NamedTuple, Optional
 
 from lxml import etree
 
 from sila2.framework.abc.data_type import DataType
 from sila2.framework.abc.named_data_node import NamedDataNode
 from sila2.framework.data_types.list import List
+from sila2.framework.pb2 import SiLAFramework_pb2
+from sila2.framework.pb2.SiLAFramework_pb2 import Any as SilaAny
 from sila2.framework.utils import xml_node_to_normalized_string
 
-if TYPE_CHECKING:
-    from sila2.pb2_stubs import SiLAFramework_pb2
-    from sila2.pb2_stubs.SiLAFramework_pb2 import Any as SilaAny
-
-
 VOID_TYPE_XML = """
 <DataType>
   <Constrained>
@@ -41,16 +37,13 @@ class SilaAnyType(NamedTuple):
     """Value of the given type"""
 
 
-class Any(DataType):
-    native_type = SilaAnyType
-    message_type: Type[SilaAny]
-
+class Any(DataType[SilaAny, SilaAnyType]):
     def __init__(self, silaframework_pb2_module: SiLAFramework_pb2):
         self.message_type = silaframework_pb2_module.Any
 
     def to_native_type(self, message: SilaAny, toplevel_named_data_node: Optional[NamedDataNode] = None) -> SilaAnyType:
         type_str = message.type
-        data_type = Any.__getdata_type(type_str)
+        data_type = self.__getdata_type(type_str)
         msg = data_type.message_type.FromString(message.payload)
         if self.__is_void(type_str):
             return SilaAnyType(type_str, None)
@@ -60,7 +53,7 @@ class Any(DataType):
         type_str, native_payload = value
         if self.__is_void(type_str):
             native_payload = ""
-        data_type = Any.__getdata_type(type_str)
+        data_type = self.__getdata_type(type_str)
         binary_payload = data_type.to_message(
             native_payload, toplevel_named_data_node=toplevel_named_data_node
         ).SerializeToString()
